==> tuia-advert-center-api-1.5.0-20180621.153018-4-sources.jar: cn/com/duiba/tuia/core/api/enums/statistics/AdvertHourStatisticsTitleEnum.java <==
package cn.com.duiba.tuia.core.api.enums.statistics;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import cn.com.duiba.tuia.core.api.dto.statistics.TitleHeader;
import cn.com.duiba.wolf.utils.BeanUtils;

import com.google.common.collect.Maps;

/**
 * 
 * ClassName: AdvertHourStatisticsTitleEnum <br/>
 * Function: 广告小时数据标题. <br/>
 * date: 2018年4月20日 下午2:15:36 <br/>
 *
 * @author chencheng
 * @version 
 * @since JDK 1.8
 */
public enum AdvertHourStatisticsTitleEnum {

    /** 时间段 */
    TIME_BUCKET(0, "timeBucket", "时间段"),
    
    /** 消费 */
    CONSUME_TOTAL(0, "consumeTotal", "消费"),
    
    /** 发券 */
    LAUNCH_COUNT(0, "launchCount", "发券"),
    
    /** 曝光 */
    EXPOSURE_COUNT(0, "exposureCount", "曝光"),
    
    /** 总点击 */
    CLICK_COUNT(0, "clickCount", "总点击"),
    
    /** 计费点击 */
    EF_CLICK_COUNT(0, "efClickCount", "计费点击"),
    
    /** 计费点击UV */
    CLICK_UV(0, "clickUV", "计费点击UV"),
    
    /** 计费点击率 */
    CLICK_RATE(0, "clickRate", "计费点击率"),
    
    /** 落地页访问PV/UV */
    VISIT_PV_UV(1, "visitPvUv", "落地页访问PV/UV"),
    
    /** 落地页访问PV */
    VISIT_PV(2, "visitPv", "落地页访问PV"),
    
    /** 落地页访问UV */
    VISIT_UV(2, "visitUv", "落地页访问UV"),
    
    /** 落地页到达率 */
    LOSS(0, "loss", "落地页到达率"),
    
    /** 转化PV/UV */
    EFFECT_PV_UV(1, "effectPvUv", "转化PV/UV"),
    
    /** 转化PV */
    EFFECT_PV(2, "effectPv", "转化PV"),
    
    /** 转化UV */
    EFFECT_UV(2, "effectUv", "转化UV"),
    
    /** 转化成本（PV）消耗/转化pv */
    EFFECT_COST(0, "effectCost", "转化成本（PV）"),
    
    /** CVR */
    CVR(0, "cvr", "CVR"),
    
    /** 计费点击均价 */
    AVERAGE_PRICE(3, "averagePrice", "计费点击均价"),
    
    /** 活动类型 */
    ACTIVITY_TYPE(5, "activityType", "活动类型");

    /** 类型：0-公用，1-页面展示标题，2-导出标题,3-转化数据后追加的公用标题，4-转化数据后追加的展示标题，5-转化数据后追加的导出标题  */
    private Integer type;
    
    private String code;

    private String desc;

    private AdvertHourStatisticsTitleEnum(Integer type, String code, String desc) {
        this.type = type;
        this.code = code;
        this.desc = desc;
    }

    public Integer getType() {
        return type;
    }

    public String getDesc() {
        return desc;
    }

    public String getCode() {
        return code;
    }

    public static AdvertHourStatisticsTitleEnum getByCode(String code) {
        return enumMap.get(code);
    }
    
    private static Map<String, AdvertHourStatisticsTitleEnum> enumMap = Maps.newHashMap();
    
    /** 固定数据标题 */
    private static List<TitleHeader> advertHourStatisticsTitleList = new ArrayList<>(AdvertHourStatisticsTitleEnum.values().length*2);
    private static List<TitleHeader> advertHourStatisticsExporyTitleList = new ArrayList<>(AdvertHourStatisticsTitleEnum.values().length*2);
    private static List<TitleHeader> advertHourOtherTitleList = new ArrayList<>(AdvertDayStatisticsTitleEnum.values().length);
    private static List<TitleHeader> advertHourOtherExportTitleList = new ArrayList<>(AdvertDayStatisticsTitleEnum.values().length);
    static {
        for (AdvertHourStatisticsTitleEnum it : AdvertHourStatisticsTitleEnum.values()) {
            enumMap.put(it.getCode(), it);
            switch (it.type) {
                case 0:
                    advertHourStatisticsTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    advertHourStatisticsExporyTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 1:
                    advertHourStatisticsTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 2:
                    advertHourStatisticsExporyTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 3:
                    advertHourOtherTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 5:
                    advertHourOtherExportTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                default:
                    break;
            }
        }
    }

    /**
     * 
     * getAdvertHourStatisticsTitle:(获取转化标题前固定标题，1-展示，2-导出). <br/>
     *
     * @author chencheng
     * @return
     * @since JDK 1.8
     */
    public static List<TitleHeader> getAdvertHourStatisticsTitle(Integer type) {
        if (type.intValue() == 1) {
            return BeanUtils.copyList(advertHourStatisticsTitleList, TitleHeader.class);
        }else{
            return BeanUtils.copyList(advertHourStatisticsExporyTitleList, TitleHeader.class);
        }
    }
    
    /**
     * 
     * addOtherTitle:(其他标题追加，转化数据标题放在这些标题之前). <br/>
     *
     * @author chencheng
     * @param advertHourStatisticsTitle
     * @since JDK 1.8
     */
    public static void addOtherTitle(List<TitleHeader> advertHourStatisticsTitle) {
        
        advertHourStatisticsTitle.addAll(advertHourOtherTitleList);
    }
    
    /**
     * 
     * addOtherTitle:(转化数据后追加的导出标题). <br/>
     *
     * @author chencheng
     * @param advertDayStatisticsTitle
     * @since JDK 1.8
     */
    public static void addOtherExportTitleList(List<TitleHeader> advertDayStatisticsTitle) {
        advertDayStatisticsTitle.addAll(advertHourOtherExportTitleList);
    }
}

==> tuia-advert-center-api-2.6.27-sources.jar: cn/com/duiba/tuia/core/api/enums/statistics/AdvertHourStatisticsTitleEnum.java <==
package cn.com.duiba.tuia.core.api.enums.statistics;

import cn.com.duiba.tuia.core.api.dto.statistics.TitleHeader;
import cn.com.duiba.wolf.utils.BeanUtils;
import com.google.common.collect.Maps;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 
 * ClassName: AdvertHourStatisticsTitleEnum <br/>
 * Function: 广告小时数据标题. <br/>
 * date: 2018年4月20日 下午2:15:36 <br/>
 *
 * @author chencheng
 * @version 
 * @since JDK 1.8
 */
public enum AdvertHourStatisticsTitleEnum {

    /** 小时 */
    TIME_BUCKET(0, "timeBucket", "小时"),
    
    /** 消费 */
    CONSUME_TOTAL(0, "consumeTotal", "消费"),

    /** 转化成本（PV）消耗/转化pv */
    EFFECT_COST(0, "effectCost", "转化成本（PV）"),
    
    /** 发券pv */
    LAUNCH_COUNT(0, "launchCount", "发券pv"),
    

    /** 计费点击pv */
    EF_CLICK_COUNT(0, "efClickCount", "计费点击pv"),
    

    /** CTR */
    CLICK_RATE(0, "clickRate", "CTR"),


    /** 落地页访问PV */
    VISIT_PV(0, "visitPv", "落地页访问PV"),

    
    /** 落地页到达率 */
    LOSS(0, "loss", "落地页到达率"),
    
    /** 转化PV */
    EFFECT_PV(0, "effectPv", "转化PV"),

    /** CVR */
    CVR(0, "cvr", "CVR"),

    /** 计费点击均价 */
    AVERAGE_PRICE(3, "averagePrice", "计费点击均价"),

    /**付费金额**/
    PAYMENT_AMOUNT(0,"paymentAmount", "付费金额"),

    /**roi**/
    ROI(0,"roi", "投放roi")
;

    /** 类型：0-公用，1-页面展示标题，2-导出标题,3-转化数据后追加的公用标题，4-转化数据后追加的展示标题，5-转化数据后追加的导出标题  */
    private Integer type;
    
    private String code;

    private String desc;

    private AdvertHourStatisticsTitleEnum(Integer type, String code, String desc) {
        this.type = type;
        this.code = code;
        this.desc = desc;
    }

    public Integer getType() {
        return type;
    }

    public String getDesc() {
        return desc;
    }

    public String getCode() {
        return code;
    }

    public static AdvertHourStatisticsTitleEnum getByCode(String code) {
        return enumMap.get(code);
    }
    
    private static Map<String, AdvertHourStatisticsTitleEnum> enumMap = Maps.newHashMap();
    
    /** 固定数据标题 */
    private static List<TitleHeader> advertHourStatisticsTitleList = new ArrayList<>(AdvertHourStatisticsTitleEnum.values().length*2);
    private static List<TitleHeader> advertHourStatisticsExporyTitleList = new ArrayList<>(AdvertHourStatisticsTitleEnum.values().length*2);
    private static List<TitleHeader> advertHourOtherTitleList = new ArrayList<>(AdvertDayStatisticsTitleEnum.values().length);
    private static List<TitleHeader> advertHourOtherExportTitleList = new ArrayList<>(AdvertDayStatisticsTitleEnum.values().length);
    static {
        for (AdvertHourStatisticsTitleEnum it : AdvertHourStatisticsTitleEnum.values()) {
            enumMap.put(it.getCode(), it);
            switch (it.type) {
                case 0:
                    advertHourStatisticsTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    advertHourStatisticsExporyTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 1:
                    advertHourStatisticsTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 2:
                    advertHourStatisticsExporyTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 3:
                    advertHourOtherTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                case 5:
                    advertHourOtherExportTitleList.add(new TitleHeader(it.getCode(), it.getDesc()));
                    break;
                default:
                    break;
            }
        }
    }

    /**
     * 
     * getAdvertHourStatisticsTitle:(获取转化标题前固定标题，1-展示，2-导出). <br/>
     *
     * @author chencheng
     * @return
     * @since JDK 1.8
     */
    public static List<TitleHeader> getAdvertHourStatisticsTitle(Integer type) {
        if (type.intValue() == 1) {
            return BeanUtils.copyList(advertHourStatisticsTitleList, TitleHeader.class);
        }else{
            return BeanUtils.copyList(advertHourStatisticsExporyTitleList, TitleHeader.class);
        }
    }
    
    /**
     * 
     * addOtherTitle:(其他标题追加，转化数据标题放在这些标题之前). <br/>
     *
     * @author chencheng
     * @param advertHourStatisticsTitle
     * @since JDK 1.8
     */
    public static void addOtherTitle(List<TitleHeader> advertHourStatisticsTitle) {
        
        advertHourStatisticsTitle.addAll(advertHourOtherTitleList);
    }
    
    /**
     * 
     * addOtherTitle:(转化数据后追加的导出标题). <br/>
     *
     * @author chencheng
     * @param advertDayStatisticsTitle
     * @since JDK 1.8
     */
    public static void addOtherExportTitleList(List<TitleHeader> advertDayStatisticsTitle) {
        advertDayStatisticsTitle.addAll(advertHourOtherExportTitleList);
    }
}
